<?php
/**
 * Theme widgets.
 *
 * @package Infinity Blog
 */

// Load widget base.
require_once get_template_directory() . '/inc/widgets/widget-base-class.php';

if (!function_exists('infinity_blog_load_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function infinity_blog_load_widgets()
    {
        // Recent Post widget.
        register_widget('TWP_sidebar_widget');

        // Auther widget.
        register_widget('TWP_Author_Post_widget');

        // Social widget.
        register_widget('TWP_Social_widget');

        // Tab post widget
        register_widget('TWP_Tab_Posts_Widget');
    }
endif;
add_action('widgets_init', 'infinity_blog_load_widgets');

/*Grid Panel widget*/
if (!class_exists('TWP_sidebar_widget')) :

    /**
     * Popular widget Class.
     *
     * @since 1.0.0
     */
    class TWP_sidebar_widget extends Infinity_Blog_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'infinity_blog_popular_post_widget',
                'description' => esc_html__('Displays post form selected category specific for popular post in sidebars.', 'infinity-blog'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'infinity-blog'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => esc_html__('Select Category:', 'infinity-blog'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'infinity-blog'),
                ),
                'post_number' => array(
                    'label' => esc_html__('Number of Posts:', 'infinity-blog'),
                    'type' => 'number',
                    'default' => 4,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 10,
                ),
            );

            parent::__construct('infinity-blog-popular-sidebar-layout', esc_html__('Infinity: Recent Post', 'infinity-blog'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if (!empty($params['title'])) {
                echo $args['before_title'] . esc_html( $params['title'] ) . $args['after_title'];
            }

            $qargs = array(
                'posts_per_page' => esc_attr($params['post_number']),
                'no_found_rows' => true,
            );
            if (absint($params['post_category']) > 0) {
                $qargs['cat'] = absint($params['post_category']);
            }
            
            $recent_posts_query = new WP_Query($qargs);
            $count = 1;
            if ($recent_posts_query->have_posts()) : ?>
            <div class="twp-recent-widget">
                <ul class="recent-widget-list">
                    <?php while ($recent_posts_query->have_posts()) :
                        $recent_posts_query->the_post(); ?>
                        <li>
                            <article class="article-list">
                                <div class="article-image">
                                    <?php if (has_post_thumbnail()) {
                                        $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'infinity-blog-related-post');
                                        $url = $thumb['0']; ?>
                                        <a href="<?php the_permalink(); ?>" class="bg-image bg-image-1">
                                            <img src="<?php echo esc_url($url); ?>" alt="<?php the_title_attribute(); ?>">
                                        </a>
                                    <?php } ?>
                                    <div class="trend-item">
                                        <span class="number"> <?php echo $count; ?></span>
                                    </div>
                                </div>
                                <div class="article-body">
                                    <div class="post-meta">
                                    <span class="posts-date">
                                        <?php echo esc_attr(get_post_time('j M Y')); ?></span>
                                    </div>
                                    <h4 class="secondary-font">
                                        <a href="<?php the_permalink(); ?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h4>
                                </div>
                            </article>
                        </li>
                        <?php
                        $count++;
                    endwhile; ?>
                </ul>
            </div>

            <?php wp_reset_postdata(); ?>

        <?php endif; ?>
            <?php echo $args['after_widget'];
        }
    }
endif;

/*author widget*/
if (!class_exists('TWP_Author_Post_widget')) :

    /**
     * Author widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Author_Post_widget extends Infinity_Blog_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'infinity_blog_author_widget',
                'description' => esc_html__('Displays authors details in post.', 'infinity-blog'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'infinity-blog'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'author-name' => array(
                    'label' => esc_html__('Name:', 'infinity-blog'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'discription' => array(
                    'label' => esc_html__('Description:', 'infinity-blog'),
                    'type' => 'textarea',
                    'class' => 'widget-content widefat'
                ),
                'image_url' => array(
                    'label' => esc_html__('Author Image:', 'infinity-blog'),
                    'type' => 'image',
                ),
                'url-fb' => array(
                    'label' => esc_html__('Facebook URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-tw' => array(
                    'label' => esc_html__('Twitter URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-ig' => array(
                    'label' => esc_html__('Instagram URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),

            );

            parent::__construct('infinity-blog-author-layout', esc_html__('Infinity: Author Widget', 'infinity-blog'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if (!empty($params['title'])) {
                echo $args['before_title'] . esc_html( $params['title'] ) . $args['after_title'];
            } ?>

            <!--cut from here-->
            <div class="author-info">
                <div class="author-image">
                    <?php if (!empty($params['image_url'])) { ?>
                        <div class="profile-image text-center bg-image" >
                            <img src="<?php echo esc_url($params['image_url']); ?>">
                        </div>
                    <?php } ?>
                </div> <!-- /#author-image -->
                <div class="author-social">
                    <?php if (!empty($params['url-fb'])) { ?>
                            <a href="<?php echo esc_url($params['url-fb']); ?>" target="_blank">
                                <i class="meta-icon ion-social-facebook"></i>
                            </a>
                    <?php } ?>
                    <?php if (!empty($params['url-tw'])) { ?>
                            <a href="<?php echo esc_url($params['url-tw']); ?>" target="_blank">
                                <i class="social-icon ion-social-twitter"></i>
                            </a>
                    <?php } ?>
                    <?php if (!empty($params['url-ig'])) { ?>
                            <a href="<?php echo esc_url($params['url-ig']); ?>" target="_blank">
                                <i class="social-icon ion-social-instagram"></i>
                            </a>
                    <?php } ?>
                </div><!-- /#author-social -->
                <div class="author-details text-center">
                    <?php if (!empty($params['author-name'])) { ?>
                        <h3 class="author-name"><?php echo esc_html($params['author-name']); ?></h3>
                    <?php } ?>
                    <?php if (!empty($params['discription'])) { ?>
                        <p><?php echo wp_kses_post($params['discription']); ?></p>
                    <?php } ?>
                </div> <!-- /#author-details -->
            </div>
            <?php echo $args['after_widget'];
        }
    }
endif;

/*Social widget*/
if (!class_exists('TWP_Social_widget')) :

    /**
     * Social widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Social_widget extends Infinity_Blog_Widget_Base
    {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'infinity_blog_social_widget',
                'description' => esc_html__('Displays Social share.', 'infinity-blog'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'infinity-blog'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'url-fb' => array(
                    'label' => esc_html__('Facebook URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-tw' => array(
                    'label' => esc_html__('Twitter URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-ig' => array(
                    'label' => esc_html__('Googleplus URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-lt' => array(
                    'label' => esc_html__('Linkedin URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-ig' => array(
                    'label' => esc_html__('Instagram URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-pt' => array(
                    'label' => esc_html__('Pinterest URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-rt' => array(
                    'label' => esc_html__('Reddit URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-sk' => array(
                    'label' => esc_html__('Skype URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-sc' => array(
                    'label' => esc_html__('Snapchat URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-tr' => array(
                    'label' => esc_html__('Tumblr URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-th' => array(
                    'label' => esc_html__('Twitch URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-yt' => array(
                    'label' => esc_html__('Youtube URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-vo' => array(
                    'label' => esc_html__('Vimeo URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-wa' => array(
                    'label' => esc_html__('Whatsapp URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-wp' => array(
                    'label' => esc_html__('WordPress URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-gh' => array(
                    'label' => esc_html__('Github URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-fs' => array(
                    'label' => esc_html__('FourSquare URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
                'url-db' => array(
                    'label' => esc_html__('Dribbble URL:', 'infinity-blog'),
                    'type' => 'url',
                    'class' => 'widefat',
                ),
            );

            parent::__construct('infinity-blog-social-layout', esc_html__('Infinity: Social Widget', 'infinity-blog'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget($args, $instance)
        {

            $params = $this->get_params($instance);

            echo $args['before_widget'];

            if (!empty($params['title'])) {
                echo $args['before_title'] . esc_html( $params['title'] ) . $args['after_title'];
            } ?>

            <div class="twp-social-widget">
                <ul class="social-widget-wrapper">
                    <?php if (!empty($params['url-fb'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-fb']); ?>" target="_blank">
                                <i class="meta-icon ion-social-facebook"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-tw'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-tw']); ?>" target="_blank">
                                <i class="social-icon ion-social-twitter"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-ig'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-ig']); ?>" target="_blank">
                                <i class="social-icon ion-social-instagram"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-lt'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-lt']); ?>" target="_blank">
                                <i class="social-icon ion-social-linkedin"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-ig'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-ig']); ?>" target="_blank">
                                <i class="social-icon ion-social-instagram"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-pt'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-pt']); ?>" target="_blank">
                                <i class="social-icon ion-social-pinterest"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-rt'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-rt']); ?>" target="_blank">
                                <i class="social-icon ion-social-reddit"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-sk'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-sk']); ?>" target="_blank">
                                <i class="social-icon ion-social-skype"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-sc'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-sc']); ?>" target="_blank">
                                <i class="social-icon ion-social-snapchat"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-tr'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-tr']); ?>" target="_blank">
                                <i class="social-icon ion-social-tumblr"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-th'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-th']); ?>" target="_blank">
                                <i class="social-icon ion-social-twitch"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-yt'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-yt']); ?>" target="_blank">
                                <i class="social-icon ion-social-youtube"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-vo'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-vo']); ?>" target="_blank">
                                <i class="social-icon ion-social-vimeo"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-wa'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-wa']); ?>" target="_blank">
                                <i class="social-icon ion-social-whatsapp"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-wp'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-wp']); ?>" target="_blank">
                                <i class="social-icon ion-social-wordpress"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-gh'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-gh']); ?>" target="_blank">
                                <i class="social-icon ion-social-github"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-fs'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-fs']); ?>" target="_blank">
                                <i class="social-icon ion-social-foursquare"></i>
                            </a>
                        </li>
                    <?php } ?>
                    <?php if (!empty($params['url-db'])) { ?>
                        <li>
                            <a href="<?php echo esc_url($params['url-db']); ?>" target="_blank">
                                <i class="social-icon ion-social-dribbble"></i>
                            </a>
                        </li>
                    <?php } ?>

                </ul>
            </div>
            <?php echo $args['after_widget'];
        }
    }
endif;

/* Tabed widget */
if ( !class_exists('TWP_Tab_Posts_Widget') ):

    /**
     * Tabbed widget Class.
     *
     * @since 1.0.0
     */
    class TWP_Tab_Posts_Widget extends Infinity_Blog_Widget_Base {

        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct() {

            $opts = array(
                'classname'   => 'infinity_blog_widget_tabbed',
                'description' => esc_html__('Tabbed widget.', 'infinity-blog'),
            );
            $fields = array(
                'popular_heading' => array(
                    'label'          => esc_html__('Popular', 'infinity-blog'),
                    'type'           => 'heading',
                ),
                'popular_number' => array(
                    'label'         => esc_html__('No. of Posts:', 'infinity-blog'),
                    'type'          => 'number',
                    'css'           => 'max-width:60px;',
                    'default'       => 5,
                    'min'           => 1,
                    'max'           => 10,
                ),
                'select_image_size' => array(
                    'label' => esc_html__('Select Image Size Featured Post:', 'infinity-blog'),
                    'type' => 'select',
                    'default' => 'medium',
                    'options' => array(
                        'thumbnail' => esc_html__('Thumbnail', 'infinity-blog'),
                        'medium' => esc_html__( 'Medium', 'infinity-blog' ),
                        'large' => esc_html__( 'Large', 'infinity-blog' ),
                        'full' => esc_html__( 'Full', 'infinity-blog' ),
                    ),

                ),
                'excerpt_length' => array(
                    'label'         => esc_html__('Excerpt Length:', 'infinity-blog'),
                    'description'   => esc_html__('Number of words', 'infinity-blog'),
                    'default'       => 10,
                    'css'           => 'max-width:60px;',
                    'min'           => 0,
                    'max'           => 200,
                ),
                'recent_heading' => array(
                    'label'         => esc_html__('Recent', 'infinity-blog'),
                    'type'          => 'heading',
                ),
                'recent_number' => array(
                    'label'        => esc_html__('No. of Posts:', 'infinity-blog'),
                    'type'         => 'number',
                    'css'          => 'max-width:60px;',
                    'default'      => 5,
                    'min'          => 1,
                    'max'          => 10,
                ),
                'comments_heading' => array(
                    'label'           => esc_html__('Comments', 'infinity-blog'),
                    'type'            => 'heading',
                ),
                'comments_number' => array(
                    'label'          => esc_html__('No. of Comments:', 'infinity-blog'),
                    'type'           => 'number',
                    'css'            => 'max-width:60px;',
                    'default'        => 5,
                    'min'            => 1,
                    'max'            => 10,
                ),
                'tagged_heading' => array(
                    'label'           => esc_html__('Tagged', 'infinity-blog'),
                    'type'            => 'heading',
                ),
            );

            parent::__construct( 'infinity-blog-tabbed', esc_html__( 'Infinity: Tab Posts Widget', 'infinity-blog' ), $opts, array(), $fields );

        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         */
        function widget( $args, $instance ) {

            $params = $this->get_params( $instance );
            $tab_id = 'tabbed-'.$this->number;

            echo $args['before_widget'];
            ?>
            <div class="tabbed-container">

                <div class="tab-head">
                    <ul class="twp-nav-tabs clear">

                        <li tab-data="tab-popular" class="infinity-blog-tab tab-popular active">
                            <a href="javascript:void(0)">
                                <span class="ion-ios-star-outline tab-icon">

                                </span>
                            </a>
                        </li>

                        <li tab-data="tab-recent" class="infinity-blog-tab tab-recent">
                            <a href="javascript:void(0)">
                                <span class="ion-ios-bolt-outline tab-icon">

                                </span>
                            </a>
                        </li>

                        <li tab-data="tab-comments" class="infinity-blog-tab tab-comments">
                            <a href="javascript:void(0)">
                                <span class="ion-ios-chatboxes-outline tab-icon">

                                </span>
                            </a>
                        </li>
                        <li tab-data="tab-tagged" class="infinity-blog-tab tab-tagged">
                            <a href="javascript:void(0)">
                                <span class="ion-ios-pricetags-outline tab-icon">

                                </span>
                            </a>
                        </li>

                    </ul>
                </div>

                <div class="tab-content">

                    <div class="tab-pane content-tab-popular active">
                        <?php $this->render_news( 'popular', $params );?>
                    </div>

                    <div class="tab-pane content-tab-recent">
                        <?php $this->render_news('recent', $params );?>
                    </div>

                    <div class="tab-pane content-tab-comments">
                        <?php $this->render_comments( $params );?>
                    </div>

                    <div class="tab-pane content-tab-tagged">
                        <?php $this->render_tagged( $params );?>
                    </div>

                </div>

            </div>
            <?php

            echo $args['after_widget'];

        }

        /**
         * Render news.
         *
         * @since 1.0.0
         *
         * @param array $type Type.
         * @param array $params Parameters.
         * @return void
         */
        function render_news($type, $params) {

            if ( !in_array( $type, array('popular', 'recent') ) ) {
                return;
            }

            switch ($type) {
                case 'popular':

                    $cat_slug = '';
                    if( isset( $params['tab_cat'] ) ){
                        $cat_slug = $params['tab_cat'];
                    }

                    $qargs = array(
                        'posts_per_page' => $params['popular_number'],
                        'no_found_rows'  => true,
                        'orderby'        => 'comment_count',
                        'category_name'  => $cat_slug,
                    );

                    break;

                case 'recent':

                    $cat_slug = '';
                    if( isset( $params['tab_cat'] ) ){
                        $cat_slug = $params['tab_cat'];
                    }

                    $qargs = array(
                        'posts_per_page' => $params['recent_number'],
                        'no_found_rows'  => true,
                        'category_name'  => $cat_slug,
                    );

                    break;

                default:
                    break;
            }

            $tab_posts_query = new WP_Query( $qargs );

            if ( $tab_posts_query->have_posts() ): ?>

                <ul class="theme-widget-list recent-widget-list">

                    <?php
                    while ( $tab_posts_query->have_posts() ):
                        $tab_posts_query->the_post(); ?>

                        <li>
                            <article class="article-list">
                                <div class="article-image">
                                    <?php
                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium');
                                    $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                    <a href="<?php the_permalink(); ?>" class="data-bg bg-image-1" data-background="<?php echo esc_url($featured_image); ?>"></a>

                                </div>

                                <div class="article-body">

                                    <div class="entry-meta">
                                        <span class="posted-on">
                                            <?php echo esc_attr(get_post_time('j M Y')); ?>
                                        </span>
                                    </div>

                                    <h3 class="entry-title entry-title-small primary-font">
                                        <a href="<?php the_permalink(); ?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h3>
                                </div>
                            </article>
                        </li>

                    <?php endwhile;?>

                </ul><!-- .news-list -->

                <?php wp_reset_postdata();

            endif;

        }

        /**
         * Render comments.
         *
         * @since 1.0.0
         *
         * @param array $params Parameters.
         * @return void
         */
        function render_comments($params) {

            $cat_slug = '';
            $post_array = array();
            if( !empty( $params['tab_cat'] ) ){

                $cat_slug = $params['tab_cat'];

                $qargs = array(
                    'posts_per_page' => 10,
                    'no_found_rows'  => true,
                    'category_name'  => $cat_slug,
                );

                $tab_posts_query = new WP_Query( $qargs );

                if ( $tab_posts_query->have_posts() ){

                    while ( $tab_posts_query->have_posts() ){
                        $tab_posts_query->the_post();
                        $post_array[] = get_the_ID();
                    }
                    wp_reset_postdata();
                }
            }

            $comment_args = array(
                'number'      => $params['comments_number'],
                'status'      => 'approve',
                'post_status' => 'publish',
                'post__in'  => $post_array,
            );

            $comments = get_comments( $comment_args );
            ?>
            <?php if ( !empty( $comments ) ):?>
                <ul class="theme-widget-list comments-tabbed-list">
                    <?php foreach ( $comments as $key => $comment ):?>
                        <li>
                            <article class="article-list">
                                <div class="article-image">
                                    <?php $comment_author_url = esc_url( get_comment_author_url( $comment ) ); ?>
                                    <?php if ( !empty( $comment_author_url ) ):

                                        $thumb = get_avatar_url( $comment, array('size'=>100) ); ?>

                                        <a href="<?php echo esc_url( $comment_author_url ); ?>" class="data-bg bg-image-1" data-background="<?php echo esc_url( $thumb ); ?>"></a>

                                    <?php  else : ?>
                                        <?php echo wp_kses_post( get_avatar( $comment, 130 ) );?>
                                    <?php endif;?>
                                </div>

                                <div class="article-body">
                                    <div class="comments-content">
                                        <?php echo wp_kses_post(get_comment_author_link($comment)); ?>
                                    </div>
                                    <h3 class="entry-title entry-title-small primary-font">
                                        <a href="<?php echo esc_url(get_comment_link($comment)); ?>">
                                            <?php echo esc_html(get_the_title($comment->comment_post_ID)); ?>
                                        </a>
                                    </h3>
                                </div>
                            </article>
                        </li>
                    <?php endforeach;?>
                </ul><!-- .comments-list -->
            <?php endif;?>
            <?php
        }
        /**
         * Render Tagged.
         *
         * @since 1.0.0
         *
         * @param array $params Parameters.
         * @return void
         */
        function render_tagged($params) {
            $tags = get_tags();
            $args = array(
                'smallest'                  => 10,
                'largest'                   => 22,
                'unit'                      => 'px',
                'format'                    => 'flat',
                'separator'                 => " ",
                'orderby'                   => 'count',
                'order'                     => 'DESC',
                'show_count'                => 1,
                'echo'                      => false
            );

            $tag_string = wp_generate_tag_cloud( $tags, $args );

            echo $tag_string;

        }

    }
endif;
